@@ -587,8 +587,8 @@ _SEQDB = {
     '> CSI 1"q'          : 'DECSCA 1 / select character protection attribute: DECSED and DECSEL cannot erase',
     '> CSI 2"q'          : 'DECSCA 2 / select character protection attribute: DECSED and DECSEL can erase',
     '> CSI r'            : 'DECSTBM / set top and bottom margins',
-    '> CSI ?r'           : 'save DEC private mode values',
-    '> CSI ?s'           : 'restore DEC private mode values',
+    '> CSI ?s'           : 'save DEC private mode values',
+    '> CSI ?r'           : 'restore DEC private mode values',
     '> CSI t'            : 'DECSLPP or Window Manipulation (dtterm)',
     '> CSI 1t'           : 'Window Manipulation (dtterm) 1: de-iconify window',
     '> CSI 2t'           : 'Window Manipulation (dtterm) 2: iconify window',
